@@ -1,6 +1,5 @@
 from setuptools import Extension
 from setuptools.command.build_py import build_py as build_py_orig
-from setuptools.command.bdist_egg import bdist_egg as _bdist_egg
 import shutil
 
 from Cython.Build import cythonize
@@ -24,28 +23,22 @@ class build_py(build_py_orig):
         pass
 
 
-def get_bdist_egg(setup_py):
-    class bdist_egg(_bdist_egg):
-        def run(self):
-            _bdist_egg.run(self)
-            # Do something magical
-            if os.environ.get('NO_CLEAR_ARTIPY') == "1":
-                return
-            else:
-                dirname = os.path.split(setup_py)[0]
-                shutil.rmtree(os.path.join(dirname, "build"))
-                for root, subdirs, files in os.walk(dirname):
-                    for fname in os.listdir(root):
-                        fname.endswith('.c')
-                        os.remove(fname)
-    return bdist_egg
-
-
 def artipy(dirname, setup_py):
     if os.environ.get('DISABLE_ARTIPY') == "1":
         return {}
     else:
         return {
             'ext_modules': cythonize(find_extensions(dirname, setup_py)),
-            'cmdclass': {'build_py': build_py, 'bdist_egg': get_bdist_egg(setup_py)},
+            'cmdclass': {'build_py': build_py},
         }
+
+def clean(setup_py):
+    if os.environ.get('NO_CLEAR_ARTIPY') == "1":
+        return
+    else:
+        dirname = os.path.split(setup_py)[0]
+        shutil.rmtree(os.path.join(dirname, "build"))
+        for root, subdirs, files in os.walk(dirname):
+            for fname in os.listdir(root):
+                fname.endswith('.c')
+                os.remove(fname)
\ No newline at end of file
